import * as pulumi from "@pulumi/pulumi";
/**
 * Specifies a route in a route table. For more information, see [Routes](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Route_Tables.html#route-table-routes) in the *Amazon VPC User Guide*.
 *  You must specify either a destination CIDR block or prefix list ID. You must also specify exactly one of the resources as the target.
 *  If you create a route that references a transit gateway in the same template where you create the transit gateway, you must declare a dependency on the transit gateway attachment. The route table cannot use the transit gateway until it has successfully attached to the VPC. Add a [DependsOn Attribute](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-dependson.html) in the ``AWS::EC2::Route`` resource to explicitly declare a dependency on the ``AWS::EC2::TransitGatewayAttachment`` resource.
 */
export declare class Route extends pulumi.CustomResource {
    /**
     * Get an existing Route resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Route;
    /**
     * Returns true if the given object is an instance of Route.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Route;
    /**
     * The ID of the carrier gateway.
     *  You can only use this option when the VPC contains a subnet which is associated with a Wavelength Zone.
     */
    readonly carrierGatewayId: pulumi.Output<string | undefined>;
    /**
     * The IPv4 CIDR block.
     */
    readonly cidrBlock: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the core network.
     */
    readonly coreNetworkArn: pulumi.Output<string | undefined>;
    /**
     * The IPv4 CIDR address block used for the destination match. Routing decisions are based on the most specific match. We modify the specified CIDR block to its canonical form; for example, if you specify ``100.68.0.18/18``, we modify it to ``100.68.0.0/18``.
     */
    readonly destinationCidrBlock: pulumi.Output<string | undefined>;
    /**
     * The IPv6 CIDR block used for the destination match. Routing decisions are based on the most specific match.
     */
    readonly destinationIpv6CidrBlock: pulumi.Output<string | undefined>;
    /**
     * The ID of a prefix list used for the destination match.
     */
    readonly destinationPrefixListId: pulumi.Output<string | undefined>;
    /**
     * [IPv6 traffic only] The ID of an egress-only internet gateway.
     */
    readonly egressOnlyInternetGatewayId: pulumi.Output<string | undefined>;
    /**
     * The ID of an internet gateway or virtual private gateway attached to your VPC.
     */
    readonly gatewayId: pulumi.Output<string | undefined>;
    /**
     * The ID of a NAT instance in your VPC. The operation fails if you specify an instance ID unless exactly one network interface is attached.
     */
    readonly instanceId: pulumi.Output<string | undefined>;
    /**
     * The ID of the local gateway.
     */
    readonly localGatewayId: pulumi.Output<string | undefined>;
    /**
     * [IPv4 traffic only] The ID of a NAT gateway.
     */
    readonly natGatewayId: pulumi.Output<string | undefined>;
    /**
     * The ID of a network interface.
     */
    readonly networkInterfaceId: pulumi.Output<string | undefined>;
    /**
     * The ID of the route table for the route.
     */
    readonly routeTableId: pulumi.Output<string>;
    /**
     * The ID of a transit gateway.
     */
    readonly transitGatewayId: pulumi.Output<string | undefined>;
    /**
     * The ID of a VPC endpoint. Supported for Gateway Load Balancer endpoints only.
     */
    readonly vpcEndpointId: pulumi.Output<string | undefined>;
    /**
     * The ID of a VPC peering connection.
     */
    readonly vpcPeeringConnectionId: pulumi.Output<string | undefined>;
    /**
     * Create a Route resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: RouteArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Route resource.
 */
export interface RouteArgs {
    /**
     * The ID of the carrier gateway.
     *  You can only use this option when the VPC contains a subnet which is associated with a Wavelength Zone.
     */
    carrierGatewayId?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the core network.
     */
    coreNetworkArn?: pulumi.Input<string>;
    /**
     * The IPv4 CIDR address block used for the destination match. Routing decisions are based on the most specific match. We modify the specified CIDR block to its canonical form; for example, if you specify ``100.68.0.18/18``, we modify it to ``100.68.0.0/18``.
     */
    destinationCidrBlock?: pulumi.Input<string>;
    /**
     * The IPv6 CIDR block used for the destination match. Routing decisions are based on the most specific match.
     */
    destinationIpv6CidrBlock?: pulumi.Input<string>;
    /**
     * The ID of a prefix list used for the destination match.
     */
    destinationPrefixListId?: pulumi.Input<string>;
    /**
     * [IPv6 traffic only] The ID of an egress-only internet gateway.
     */
    egressOnlyInternetGatewayId?: pulumi.Input<string>;
    /**
     * The ID of an internet gateway or virtual private gateway attached to your VPC.
     */
    gatewayId?: pulumi.Input<string>;
    /**
     * The ID of a NAT instance in your VPC. The operation fails if you specify an instance ID unless exactly one network interface is attached.
     */
    instanceId?: pulumi.Input<string>;
    /**
     * The ID of the local gateway.
     */
    localGatewayId?: pulumi.Input<string>;
    /**
     * [IPv4 traffic only] The ID of a NAT gateway.
     */
    natGatewayId?: pulumi.Input<string>;
    /**
     * The ID of a network interface.
     */
    networkInterfaceId?: pulumi.Input<string>;
    /**
     * The ID of the route table for the route.
     */
    routeTableId: pulumi.Input<string>;
    /**
     * The ID of a transit gateway.
     */
    transitGatewayId?: pulumi.Input<string>;
    /**
     * The ID of a VPC endpoint. Supported for Gateway Load Balancer endpoints only.
     */
    vpcEndpointId?: pulumi.Input<string>;
    /**
     * The ID of a VPC peering connection.
     */
    vpcPeeringConnectionId?: pulumi.Input<string>;
}
